Mesa (master): i965: Correct misspellings of "invariant".

Kenneth Graunke kwg at kemper.freedesktop.org
Sun Jan 8 04:03:04 UTC 2012


Module: Mesa
Branch: master
Commit: 6a26005c1e298ec205c339b1b53b3dff6e1fd03c
URL:    http://cgit.freedesktop.org/mesa/mesa/commit/?id=6a26005c1e298ec205c339b1b53b3dff6e1fd03c

Author: Kenneth Graunke <kenneth at whitecape.org>
Date:   Sat Jan  7 19:56:54 2012 -0800

i965: Correct misspellings of "invariant".

$ dict invarient
No definitions found for "invarient", perhaps you mean:
gcide:  Invariant
wn:  invariant

Signed-off-by: Kenneth Graunke <kenneth at whitecape.org>

---

 src/mesa/drivers/dri/i965/brw_misc_state.c   |    8 ++++----
 src/mesa/drivers/dri/i965/brw_state.h        |    2 +-
 src/mesa/drivers/dri/i965/brw_state_upload.c |    6 +++---
 src/mesa/drivers/dri/i965/brw_wm_pass0.c     |    2 +-
 4 files changed, 9 insertions(+), 9 deletions(-)

diff --git a/src/mesa/drivers/dri/i965/brw_state.h b/src/mesa/drivers/dri/i965/brw_state.h
index d271569..fcfe79f 100644
--- a/src/mesa/drivers/dri/i965/brw_state.h
+++ b/src/mesa/drivers/dri/i965/brw_state.h
@@ -45,7 +45,7 @@ extern const struct brw_tracked_state brw_vs_pull_constants;
 extern const struct brw_tracked_state brw_wm_pull_constants;
 extern const struct brw_tracked_state brw_constant_buffer;
 extern const struct brw_tracked_state brw_curbe_offsets;
-extern const struct brw_tracked_state brw_invarient_state;
+extern const struct brw_tracked_state brw_invariant_state;
 extern const struct brw_tracked_state brw_gs_prog;
 extern const struct brw_tracked_state brw_gs_unit;
 extern const struct brw_tracked_state brw_line_stipple;
diff --git a/src/mesa/drivers/dri/i965/brw_state_upload.c b/src/mesa/drivers/dri/i965/brw_state_upload.c
index 7ea5e21..c7b796c 100644
--- a/src/mesa/drivers/dri/i965/brw_state_upload.c
+++ b/src/mesa/drivers/dri/i965/brw_state_upload.c
@@ -84,7 +84,7 @@ static const struct brw_tracked_state *gen4_atoms[] =
 
    /* Command packets:
     */
-   &brw_invarient_state,
+   &brw_invariant_state,
    &brw_state_base_address,
 
    &brw_binding_table_pointers,
@@ -121,7 +121,7 @@ static const struct brw_tracked_state *gen6_atoms[] =
    &gen6_sf_vp,
 
    /* Command packets: */
-   &brw_invarient_state,
+   &brw_invariant_state,
 
    /* must do before binding table pointers, cc state ptrs */
    &brw_state_base_address,
@@ -187,7 +187,7 @@ const struct brw_tracked_state *gen7_atoms[] =
    &brw_wm_prog,
 
    /* Command packets: */
-   &brw_invarient_state,
+   &brw_invariant_state,
 
    /* must do before binding table pointers, cc state ptrs */
    &brw_state_base_address,
diff --git a/src/mesa/drivers/dri/i965/brw_wm_pass0.c b/src/mesa/drivers/dri/i965/brw_wm_pass0.c
index ccf9dc2..5a9eb0a 100644
--- a/src/mesa/drivers/dri/i965/brw_wm_pass0.c
+++ b/src/mesa/drivers/dri/i965/brw_wm_pass0.c
@@ -203,7 +203,7 @@ static const struct brw_wm_ref *pass0_get_reg( struct brw_wm_compile *c,
 	 switch (plist->Parameters[idx].Type) {
 	 case PROGRAM_NAMED_PARAM:
 	 case PROGRAM_CONSTANT:
-	    /* These are invarient:
+	    /* These are invariant:
 	     */
 	    ref = get_const_ref(c, &plist->ParameterValues[idx][component].f);
 	    break;




More information about the mesa-commit mailing list
diff --git a/src/mesa/drivers/dri/i965/brw_misc_state.c b/src/mesa/drivers/dri/i965/brw_misc_state.c
index e2ac170..1c0c52b 100644
--- a/src/mesa/drivers/dri/i965/brw_misc_state.c
+++ b/src/mesa/drivers/dri/i965/brw_misc_state.c
@@ -630,10 +630,10 @@ const struct brw_tracked_state brw_line_stipple = {
 
 
 /***********************************************************************
  * Misc invarient state packets
  */
 
-static void upload_invarient_state( struct brw_context *brw )
+static void upload_invariant_state( struct brw_context *brw )
 {
    struct intel_context *intel = &brw->intel;
 
@@ -695,13 +695,13 @@ static void upload_invarient_state( struct brw_context *brw )
    ADVANCE_BATCH();
 }
 
-const struct brw_tracked_state brw_invarient_state = {
+const struct brw_tracked_state brw_invariant_state = {
    .dirty = {
       .mesa = 0,
       .brw = BRW_NEW_CONTEXT,
       .cache = 0
    },
-   .emit = upload_invarient_state
+   .emit = upload_invariant_state
 };
 
 /**
@@ -630,10 +630,10 @@ const struct brw_tracked_state brw_line_stipple = {
 
 /***********************************************************************
- * Misc invarient state packets
+ * Misc invariant state packets
  */
 